Installation — Django Stories 1.0 documentation

Django Stories 1.0 documentation

# Installation

- Table of Contents
- index
  modules
  next
  previous

# Installation

## Using PIP

    $ pip install django-stories

## Download

Download the app here and run...

    $ python setup.py install

## Install

Add stories to your settings INSTALLED_APPS,

    INSTALLED_APPS = (
        ...
        'stories',
        ...
    )

If you want to use story_relations, add the app to INSTALLED_APPS as well.

New in version 1.0.

    INSTALLED_APPS = (
        ...
        'stories',
        'stories.relations',
        ...
    )

## Requirements

Changed in version 1.0: The only requirement is BeautifulSoup for pagination

    $ pip install BeautifulSoup

### Other Requirements

Stories may also require a couple django apps to be installed.

- sites
- contenttypes (required if you use story relations)
- auth (required, unless you specify a custom author model)

## Run syncdb

    $ ./manage.py syncdb

If your using `South` run

New in version 1.0.

    $ ./manage.py syncdb --migrate

Note

The initial migration for stories is a little special, if you plan to use a custom author model, please consult Custom Author Model Guide